@@ -10,9 +10,16 @@ from Products.CMFCore.utils import getToolByName
 from Products.CMFPlone.PloneBatch import Batch
 from datetime import date
 from DateTime import DateTime
+
+from plone.registry.interfaces import IRegistry
+from plone.app.event.interfaces import IEventSettings
+from plone.event.interfaces import IEventAccessor
+from plone.event.utils import default_timezone as fallback_default_timezone
+
 from plone.app.querystring import queryparser
 from collective.media.interfaces import ICanContainMedia
 from collective.portlet.relateditems.relateditems import Renderer as RelatedItemsRenderer
+from plone.app.event.browser.event_listing import EventListing as AppEventListing
 from plone.portlet.collection.collection import Renderer as CollectionPortletRenderer
 from collective.portlet.manualRelated.manualrelatedportlet import Renderer as ManualRelatedPortletRenderer
 import re
@@ -21,6 +28,7 @@ import json
 from zope.component import getMultiAdapter
 from Acquisition import aq_inner, aq_parent
 from ZTUtils import make_query
+from zope.app.component.hooks import getSite
 
 from plone.i18n.normalizer.interfaces import IIDNormalizer
 from zope.component import queryUtility
@@ -36,6 +44,7 @@ from Products.CMFCore.interfaces import ISiteRoot
 from plone.app.registry.browser.controlpanel import ControlPanelFormWrapper
 from plone.app.registry.browser.controlpanel import RegistryEditForm
 from Products.statusmessages.interfaces import IStatusMessage
+from plone.app.event.recurrence import Occurrence
 
 try:
     from Products.PloneGetPaid.interfaces import IBuyableMarker
@@ -137,10 +146,26 @@ class CommonBrowserView(BrowserView):
             item = brains[0]
         
         for tag in item.Subject:
-            classes.append("tag_%s"%tag.replace(" ", "_"))
+            classes.append("tag_%s"%tag)
         
         return " ".join(classes)
     
+    def getReviewState(self, item):
+        if hasattr(item, 'review_state'):
+            return item.review_state
+        else:
+            catalog = getToolByName(self.context, 'portal_catalog')
+            brains = catalog.queryCatalog({"UID": item.UID()})
+            item = brains[0]
+            return item.review_state
+        
+    def getEventFromOccurence(self, occ):
+        context = occ.context
+        if isinstance(context, Occurrence):
+            return context.getParentNode()
+        else:
+            return occ.context
+    
     def slideshow(self, parent):
         """
         Creates a slideshow with the media from parent
@@ -154,8 +179,45 @@ class CommonBrowserView(BrowserView):
         
         return structure
     
+    def checkYoutubeLink(self, link):
+        """
+        Check if a URL is a youtube video
+        """
+        isYoutube = link.find("youtube") != -1
+        youtubeId = ""
+        amp = link.find("&")
+    
+        if isYoutube and amp != -1:
+            youtubeId = link[link.find("?v=")+3:amp]
+        elif isYoutube and amp == -1:
+            youtubeId = link[link.find("?v=")+3:]
+    
+        return isYoutube, youtubeId
+        
+    def checkVimeoLink(self, link):
+        """
+        Check if URL is a vimeo video
+        """
+        isVimeo = link.find("vimeo") != -1
+        vimeoId = ""
+        
+        if isVimeo:
+            vimeoId = link.split("vimeo.com/")[1]
+            
+        return isVimeo, vimeoId
+    
     def getLeadMediaTag(self, item, scale="large"):
         catalog = getToolByName(self.context, 'portal_catalog')
+        if item.portal_type == 'Link':
+            isYoutube, youtubeId = self.checkYoutubeLink(item.getRemoteUrl)
+            isVimeo, vimeoId = self.checkVimeoLink(item.getRemoteUrl)
+            embed = ""
+            
+            if isYoutube:
+                return '<iframe id="'+youtubeId+'" width="100%" height="393" src="http://www.youtube.com/embed/'+youtubeId+'?rel=0&enablejsapi=1" frameborder="0" allowfullscreen></iframe>'
+            elif isVimeo:
+                return '<iframe src="http://player.vimeo.com/video/'+vimeoId+'?title=0&amp;byline=0&amp;portrait=0" width="100%" height="393" frameborder="0"></iframe>'
+            
         if item.portal_type == 'Image':
             if hasattr(item, 'getURL'):
                 lead = item.getURL()
@@ -181,17 +243,10 @@ class CommonBrowserView(BrowserView):
                 lead = None
             
         if lead is not None:
-            canCrop = self.checkPermission(item, "Modify portal content") and scale == 'crop'
-            crop = ""
-            
-            if canCrop:
-                cropLink = "%s/@@croppingeditor"%lead
-                crop = '<div class="cropButton" onclick="window.location = \'%s\'; return false;">Crop</div>'%cropLink
-            
             if hasattr(item, 'getURL'):
-                return '<img src="%(url)s" alt="%(title)s" title="%(title)s" />%(crop)s'%{'url': "%s/image_%s"%(lead, scale), 'title':item.Title, 'crop':crop}
+                return '<img src="%(url)s" alt="%(title)s" title="%(title)s" />'%{'url': "%s/image_%s"%(lead, scale), 'title':item.Title}
             else:
-                return '<img src="%(url)s" alt="%(title)s" title="%(title)s" />%(crop)s'%{'url': "%s/image_%s"%(lead, scale), 'title':item.Title(), 'crop':crop}
+                return '<img src="%(url)s" alt="%(title)s" title="%(title)s" />'%{'url': "%s/image_%s"%(lead, scale), 'title':item.Title()}
         else:
             return ""
 
@@ -317,16 +372,30 @@ class CommonBrowserView(BrowserView):
         """
         Formats the start and end dates properly and marks the event as past or future
         """
+        portal_timezone = None
+        reg = queryUtility(IRegistry, context=getSite(), default=None)
+        if reg:
+            portal_timezone= reg.forInterface(
+                    IEventSettings, prefix="plone.app.event").portal_timezone
+            
+        if not portal_timezone:
+            portal_timezone = fallback_default_timezone()
+        
         if event.portal_type != 'Event' and event.portal_type != 'Media Event':
             return ""
         
-        if event.start() is None or event.end() is None:
-            if event.start() is None and event.end() is None:
+        #start = event.start()
+        #end = event.end()
+        start = IEventAccessor(event).start
+        end = IEventAccessor(event).end
+        
+        if start is None or end is None:
+            if start is None and end is None:
                 return ""
             else:
                 samedate = True
         else:
-            samedate = event.start().strftime('%d - %m - %Y') == event.end().strftime('%d - %m - %Y')
+            samedate = start.strftime('%d - %m - %Y') == end.strftime('%d - %m - %Y')
             
         exceptions = ""
         
@@ -335,10 +404,10 @@ class CommonBrowserView(BrowserView):
             
         finalDatesFmt = '<div class="dates %(class)s"><span class="dateText">%(dates)s%(hours)s %(exceptions)s</span></div>'
         
-        dates = "%s"%(samedate and (event.start() is not None and event.start().strftime('%A %d %B %Y') or event.end().strftime('%A %d %B %Y')) or "%s to %s"%(event.start().strftime('%A %d %B %Y'), event.end().strftime('%A %d %B %Y')))
+        dates = "%s"%(samedate and (start is not None and start.strftime('%A %d %B %Y') or end.strftime('%A %d %B %Y')) or "%s to %s"%(start.strftime('%A %d %B %Y'), end.strftime('%A %d %B %Y')))
         
-        openingHour = event.start() is not None and event.start().strftime('%H:%M') or ""
-        closingHour = event.end() is not None and event.end().strftime('to %H:%M') or ""
+        openingHour = start is not None and start.strftime('%H:%M') or ""
+        closingHour = end is not None and end.strftime('to %H:%M') or ""
         hoursExist = 'to %s'%openingHour != closingHour
         
         hours = hoursExist and '<span class="hours">, %s %s</span>'%(openingHour, closingHour) or '<span class="hours">, %s</span>'%openingHour
@@ -648,6 +717,15 @@ class EventListingView(FolderListing):
         else:
             return u''
     
+    
+class AppEventListingView(CommonBrowserView, AppEventListing):
+    """
+    plone.app.event event listing vie for the calendar
+    """
+    
+    
+    
+    
 class SearchView(CommonBrowserView, Search):
     """
     Adding to Search view
@@ -888,4 +966,4 @@ class WeekDayForm(RegistryEditForm):
     """
 
 WeekDayFormView = wrap_form(WeekDayForm)
-    
\ No newline at end of file
+    
